Class: ShellEv::InlineResponse202Data
- Defined in:
- lib/shell_ev/models/inline_response202_data.rb
Overview
InlineResponse202Data Model.
Instance Attribute Summary collapse
-
#session_id ⇒ String
Session Id for tracking.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(session_id = nil) ⇒ InlineResponse202Data
constructor
A new instance of InlineResponse202Data.
Methods inherited from BaseModel
Constructor Details
#initialize(session_id = nil) ⇒ InlineResponse202Data
Returns a new instance of InlineResponse202Data.
33 34 35 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 33 def initialize(session_id = nil) @session_id = session_id end |
Instance Attribute Details
#session_id ⇒ String
Session Id for tracking.
14 15 16 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 14 def session_id @session_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. session_id = hash.key?('SessionId') ? hash['SessionId'] : nil # Create object from extracted values. InlineResponse202Data.new(session_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['session_id'] = 'SessionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/shell_ev/models/inline_response202_data.rb', line 24 def self.optionals [] end |