Class: ShellEv::M404ErrorResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/shell_ev/models/m404_error_response.rb

Overview

Invalid charge token with given EmaId was not found. Backend HTTP 410 should be transformed to 404.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#to_hash, #to_json

Constructor Details

#initialize(request_id = nil, status = nil, errors = SKIP) ⇒ M404ErrorResponse

Returns a new instance of M404ErrorResponse.



47
48
49
50
51
52
53
# File 'lib/shell_ev/models/m404_error_response.rb', line 47

def initialize(request_id = nil,
               status = nil,
               errors = SKIP)
  @request_id = request_id
  @status = status
  @errors = errors unless errors == SKIP
end

Instance Attribute Details

#errorsArray[M404ErrorResponseError]

Indicates overall status of the request

Returns:



24
25
26
# File 'lib/shell_ev/models/m404_error_response.rb', line 24

def errors
  @errors
end

#request_idString

Mandatory UUID (according to RFC 4122 standards) for requests and responses. This will be played back in the response from the request.

Returns:

  • (String)


16
17
18
# File 'lib/shell_ev/models/m404_error_response.rb', line 16

def request_id
  @request_id
end

#statusString

Indicates overall status of the request

Returns:

  • (String)


20
21
22
# File 'lib/shell_ev/models/m404_error_response.rb', line 20

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/shell_ev/models/m404_error_response.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('RequestId') ? hash['RequestId'] : nil
  status = hash.key?('Status') ? hash['Status'] : nil
  # Parameter is an array, so we need to iterate through it
  errors = nil
  unless hash['Errors'].nil?
    errors = []
    hash['Errors'].each do |structure|
      errors << (M404ErrorResponseError.from_hash(structure) if structure)
    end
  end

  errors = SKIP unless hash.key?('Errors')

  # Create object from extracted values.
  M404ErrorResponse.new(request_id,
                        status,
                        errors)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/shell_ev/models/m404_error_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'RequestId'
  @_hash['status'] = 'Status'
  @_hash['errors'] = 'Errors'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/shell_ev/models/m404_error_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
# File 'lib/shell_ev/models/m404_error_response.rb', line 36

def self.optionals
  %w[
    errors
  ]
end