Class: ShellEv::M429ErrorResponse
- Defined in:
- lib/shell_ev/models/m429_error_response.rb
Overview
Too Many Requests
Instance Attribute Summary collapse
-
#errors ⇒ Array[M429ErrorResponseError]
Indicates overall status of the request.
-
#request_id ⇒ String
Mandatory UUID (according to RFC 4122 standards) for requests and responses.
-
#status ⇒ String
Indicates overall status of the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id = nil, status = nil, errors = SKIP) ⇒ M429ErrorResponse
constructor
A new instance of M429ErrorResponse.
Methods inherited from BaseModel
Constructor Details
#initialize(request_id = nil, status = nil, errors = SKIP) ⇒ M429ErrorResponse
Returns a new instance of M429ErrorResponse.
46 47 48 49 50 51 52 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 46 def initialize(request_id = nil, status = nil, errors = SKIP) @request_id = request_id @status = status @errors = errors unless errors == SKIP end |
Instance Attribute Details
#errors ⇒ Array[M429ErrorResponseError]
Indicates overall status of the request
23 24 25 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 23 def errors @errors end |
#request_id ⇒ String
Mandatory UUID (according to RFC 4122 standards) for requests and responses. This will be played back in the response from the request.
15 16 17 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 15 def request_id @request_id end |
#status ⇒ String
Indicates overall status of the request
19 20 21 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 19 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('RequestId') ? hash['RequestId'] : nil status = hash.key?('Status') ? hash['Status'] : nil # Parameter is an array, so we need to iterate through it errors = nil unless hash['Errors'].nil? errors = [] hash['Errors'].each do |structure| errors << (M429ErrorResponseError.from_hash(structure) if structure) end end errors = SKIP unless hash.key?('Errors') # Create object from extracted values. M429ErrorResponse.new(request_id, status, errors) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'RequestId' @_hash['status'] = 'Status' @_hash['errors'] = 'Errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 |
# File 'lib/shell_ev/models/m429_error_response.rb', line 35 def self.optionals %w[ errors ] end |