Class: ShellEv::M503ErrorResponseError1Exception

Inherits:
APIException
  • Object
show all
Defined in:
lib/shell_ev/exceptions/m503_error_response_error1_exception.rb

Overview

503ErrorResponse_Error1 class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ M503ErrorResponseError1Exception

The constructor.

Parameters:

  • The (String)

    reason for raising an exception.

  • The (HttpResponse)

    HttpReponse of the API call.



28
29
30
31
32
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 28

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#errorsArray[M503ErrorResponseError]

Indicates overall status of the request

Returns:



23
24
25
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 23

def errors
  @errors
end

#request_idString

Mandatory UUID (according to RFC 4122 standards) for requests and responses. This will be played back in the response from the request.

Returns:

  • (String)


15
16
17
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 15

def request_id
  @request_id
end

#statusString

Indicates overall status of the request

Returns:

  • (String)


19
20
21
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 19

def status
  @status
end

Instance Method Details

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • The (Hash)

    deserialized response sent by the server in the



37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 37

def unbox(hash)
  @request_id = hash.key?('RequestId') ? hash['RequestId'] : nil
  @status = hash.key?('Status') ? hash['Status'] : nil
  # Parameter is an array, so we need to iterate through it
  @errors = nil
  unless hash['Errors'].nil?
    @errors = []
    hash['Errors'].each do |structure|
      @errors << (M503ErrorResponseError.from_hash(structure) if structure)
    end
  end

  @errors = SKIP unless hash.key?('Errors')
end