Class: ShellEv::TariffAltText
- Defined in:
- lib/shell_ev/models/tariff_alt_text.rb
Overview
TariffAltText Model.
Instance Attribute Summary collapse
-
#language ⇒ String
ISO language code.
-
#text ⇒ String
Human readable tariff description.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(language = nil, text = nil) ⇒ TariffAltText
constructor
A new instance of TariffAltText.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(language = nil, text = nil) ⇒ TariffAltText
Returns a new instance of TariffAltText.
38 39 40 41 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 38 def initialize(language = nil, text = nil) @language = language @text = text end |
Instance Attribute Details
#language ⇒ String
ISO language code
14 15 16 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 14 def language @language end |
#text ⇒ String
Human readable tariff description
18 19 20 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 18 def text @text end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. language = hash.key?('language') ? hash['language'] : nil text = hash.key?('text') ? hash['text'] : nil # Create object from extracted values. TariffAltText.new(language, text) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['language'] = 'language' @_hash['text'] = 'text' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} language: #{@language.inspect}, text: #{@text.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/shell_ev/models/tariff_alt_text.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} language: #{@language}, text: #{@text}>" end |