Class: ShellEv::M503ErrorResponseError1Exception
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- ShellEv::M503ErrorResponseError1Exception
- Defined in:
- lib/shell_ev/exceptions/m503_error_response_error1_exception.rb
Overview
503ErrorResponse_Error1 class.
Instance Attribute Summary collapse
-
#errors ⇒ Array[M503ErrorResponseError]
Indicates overall status of the request.
-
#request_id ⇒ String
Mandatory UUID (according to RFC 4122 standards) for requests and responses.
-
#status ⇒ String
Indicates overall status of the request.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ M503ErrorResponseError1Exception
constructor
The constructor.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ M503ErrorResponseError1Exception
The constructor.
28 29 30 31 32 |
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 28 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#errors ⇒ Array[M503ErrorResponseError]
Indicates overall status of the request
23 24 25 |
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 23 def errors @errors end |
#request_id ⇒ String
Mandatory UUID (according to RFC 4122 standards) for requests and responses. This will be played back in the response from the request.
15 16 17 |
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 15 def request_id @request_id end |
#status ⇒ String
Indicates overall status of the request
19 20 21 |
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 19 def status @status end |
Instance Method Details
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/shell_ev/exceptions/m503_error_response_error1_exception.rb', line 37 def unbox(hash) @request_id = hash.key?('RequestId') ? hash['RequestId'] : nil @status = hash.key?('Status') ? hash['Status'] : nil # Parameter is an array, so we need to iterate through it @errors = nil unless hash['Errors'].nil? @errors = [] hash['Errors'].each do |structure| @errors << (M503ErrorResponseError.from_hash(structure) if structure) end end @errors = SKIP unless hash.key?('Errors') end |