Class: ShellEv::ResponseError401AllOf1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellEv::ResponseError401AllOf1
- Defined in:
- lib/shell_ev/models/response_error401_all_of1.rb
Overview
ResponseError401AllOf1 Model.
Instance Attribute Summary collapse
-
#errors ⇒ Array[ResponseError401AllOf1ErrorsItems]
Details of error(s) encountered.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(errors = nil) ⇒ ResponseError401AllOf1
constructor
A new instance of ResponseError401AllOf1.
Methods inherited from BaseModel
Constructor Details
#initialize(errors = nil) ⇒ ResponseError401AllOf1
Returns a new instance of ResponseError401AllOf1.
33 34 35 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 33 def initialize(errors = nil) @errors = errors end |
Instance Attribute Details
#errors ⇒ Array[ResponseError401AllOf1ErrorsItems]
Details of error(s) encountered
14 15 16 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 14 def errors @errors end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it errors = nil unless hash['Errors'].nil? errors = [] hash['Errors'].each do |structure| errors << (ResponseError401AllOf1ErrorsItems.from_hash(structure) if structure) end end errors = nil unless hash.key?('Errors') # Create object from extracted values. ResponseError401AllOf1.new(errors) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['errors'] = 'Errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/shell_ev/models/response_error401_all_of1.rb', line 24 def self.optionals [] end |