Class: ShellEv::SuccessResponse
- Defined in:
- lib/shell_ev/models/success_response.rb
Overview
SuccessResponse Model.
Instance Attribute Summary collapse
-
#request_id ⇒ String
A unique request id in GUID format.
-
#status ⇒ ResponseBaseStatusEnum
Indicates overall status of the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id = nil, status = nil) ⇒ SuccessResponse
constructor
A new instance of SuccessResponse.
Methods inherited from BaseModel
Constructor Details
#initialize(request_id = nil, status = nil) ⇒ SuccessResponse
Returns a new instance of SuccessResponse.
39 40 41 42 43 |
# File 'lib/shell_ev/models/success_response.rb', line 39 def initialize(request_id = nil, status = nil) @request_id = request_id @status = status end |
Instance Attribute Details
#request_id ⇒ String
A unique request id in GUID format. The value is written to the Shell API Platform audit log for end to end traceability of a request.
15 16 17 |
# File 'lib/shell_ev/models/success_response.rb', line 15 def request_id @request_id end |
#status ⇒ ResponseBaseStatusEnum
Indicates overall status of the request
19 20 21 |
# File 'lib/shell_ev/models/success_response.rb', line 19 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/shell_ev/models/success_response.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('RequestId') ? hash['RequestId'] : nil status = hash.key?('Status') ? hash['Status'] : nil # Create object from extracted values. SuccessResponse.new(request_id, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/shell_ev/models/success_response.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'RequestId' @_hash['status'] = 'Status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/shell_ev/models/success_response.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/shell_ev/models/success_response.rb', line 30 def self.optionals [] end |